#[non_exhaustive]pub enum Reason {
SendError,
InternalError,
NetworkError,
RatelimitBackoff,
QueueOverflow,
}Expand description
Reasons for which a transport might drop data.
This is a subset of Reason, as defined in sentry_types because only some of those
reasons may be applicable to transports.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
SendError
Use this reason to record an error when sending an envelope.
This reason should be used, for example, if the server responds with a non-2xx HTTP
when the envelope is sent.
However, transports must never record a loss when receiving an HTTP 429
(rate-limiting) response, as the server already records a loss in this case.
InternalError
Used for an internal error.
This reason should be used, for example, if an I/O error prevents the envelope from being serialized.
Converts to Reason::InternalSdkError.
NetworkError
Used for a network error.
This reason should be used, for example, if a connection timeout or DNS error prevents the envelope from being sent.
Converts to Reason::NetworkError.
RatelimitBackoff
Used when the SDK is backing off due to a rate limit.
Converts to Reason::RatelimitBackoff
QueueOverflow
Used when the transport queue overflows.
Converts to Reason::QueueOverflow