pub struct Recorder { /* private fields */ }Expand description
A handle for a transport to record lost Sentry data.
Lost items recorded here will be aggregated into a client report and eventually sent to Sentry. We attempt to send client reports with a future envelope, so recording lost events should not lead to increased requests to Sentry.
Cloning has Arc-like semantics in the sense that clones record into the same client report
aggregator.
As client reports require atomics for aggregation, this struct’s methods are no-ops on platforms which lack support for 8-bit and/or 64-bit atomic operations.
Implementations
Sourceimpl Recorder
impl Recorder
Sourcepub fn record_lost_data<L: LossSource>(
&self,
data: &L,
reason: TransportLossReason,
)
pub fn record_lost_data<L: LossSource>( &self, data: &L, reason: TransportLossReason, )
Record an envelope item lost for a given reason.