macro_rules! release_name {
() => { ... };
}Expand description
Returns the intended release for Sentry as an Option<Cow<'static, str>>.
This can be used with ClientOptions to set the release name. It uses
the information supplied by cargo to calculate a release.
Examples
let _sentry = sentry::init(
sentry::ClientOptions::new().maybe_release(sentry::release_name!()),
);