pub struct DistributionMetric { /* private fields */ }Expand description
A distribution metric, created with distribution.
Implementations
Sourceimpl DistributionMetric
impl DistributionMetric
Sourcepub fn attribute<K, V>(self, key: K, value: V) -> Self
pub fn attribute<K, V>(self, key: K, value: V) -> Self
Adds an attribute to the metric.
Attributes are keys that can be used to filter and group metrics in Sentry. Multiple attributes can be chained. We recommend using Sentry semantic conventions for key values, where applicable.
Sourcepub fn capture(self)
pub fn capture(self)
Captures the metric on the current Hub, sending it to Sentry.
If the current hub has no client bound, the metric is dropped. To capture on a
different hub, use Hub::capture_metric.