Reason

Enum Reason 

#[non_exhaustive]
pub enum Reason { SendError, InternalSdkError, NetworkError, RatelimitBackoff, QueueOverflow, BufferOverflow, EventProcessor, BeforeSend, SampleRate, }
The reason why a telemetry item was discarded.

Valid discard reasons are listed in the develop docs; this enum may only define a subset of these data categories, but we will add further categories as we begin using them in the SDK.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


SendError

Error when sending the envelope (e.g. non-2xx HTTP response).



InternalSdkError

An internal error in the SDK, which does not fit under any other category.



NetworkError

A network error occurred while sending the envelope.



RatelimitBackoff

The SDK is backing off due to a rate limit.



QueueOverflow

An internal queue overflowed (e.g. the transport queue).



BufferOverflow

An SDK internal buffer overflowed.



EventProcessor

An event was dropped by an event processor.



BeforeSend

An event was dropped by a before_send callback.



SampleRate

An event was dropped because of error event sampling.