#[non_exhaustive]pub struct ItemLoss {
pub category: Category,
pub quantity: u64,
pub reason: Option<Reason>,
}Expand description
Information about a lost item.
This only includes the data category and the loss quantity, not the reason for the loss, hence
this is distinct from a Report.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.category: CategoryThe client report data category of the lost item.
quantity: u64The number of lost items or bytes, depending on the category.
reason: Option<Reason>In the case where this ItemLoss comes from a ClientReport which failed to get sent,
the reason why this item was lost per that original client report.
This field remains None for items which are being lost now for the first time.