LossSource

Trait LossSource 

pub trait LossSource: Sealed {
    // Required method
    fn losses(&self) -> impl Iterator<Item = ItemLoss>;
}
A trait for protocol types which can be a source of lost Sentry data if discarded.

Required Methods

fn losses(&self) -> impl Iterator<Item = ItemLoss>

Returns an iterator over the ItemLoss values to record if this value is discarded.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl LossSource for [ItemLoss]

Source

fn losses(&self) -> impl Iterator<Item = ItemLoss>

Implementors