Struct sentry_core::protocol::GpuContext
source · [−]pub struct GpuContext {Show 17 fields
pub name: String,
pub version: Option<String>,
pub driver_version: Option<String>,
pub id: Option<String>,
pub vendor_id: Option<String>,
pub vendor_name: Option<String>,
pub memory_size: Option<u32>,
pub api_type: Option<String>,
pub multi_threaded_rendering: Option<bool>,
pub npot_support: Option<bool>,
pub max_texture_size: Option<u32>,
pub graphics_shader_level: Option<String>,
pub supports_draw_call_instancing: Option<bool>,
pub supports_ray_tracing: Option<bool>,
pub supports_compute_shaders: Option<bool>,
pub supports_geometry_shaders: Option<bool>,
pub other: BTreeMap<String, Value>,
}Expand description
GPU context describes the GPU of the device.
Fields
name: StringThe name of the graphics device.
version: Option<String>The Version of the graphics device.
driver_version: Option<String>The version of the graphic device driver.
id: Option<String>The PCI identifier of the graphics device.
vendor_id: Option<String>The PCI vendor identifier of the graphics device.
vendor_name: Option<String>The vendor name as reported by the graphics device.
memory_size: Option<u32>The total GPU memory available in Megabytes.
api_type: Option<String>The device low-level API type. Examples: “Apple Metal” or “Direct3D11”
multi_threaded_rendering: Option<bool>Whether the GPU has multi-threaded rendering or not.
npot_support: Option<bool>The Non-Power-Of-Two-Support support.
max_texture_size: Option<u32>Largest size of a texture that is supported by the graphics hardware.
graphics_shader_level: Option<String>Approximate “shader capability” level of the graphics device. For example,
Shader Model 2.0, OpenGL ES 3.0, Metal / OpenGL ES 3.1, 27 (unknown).
supports_draw_call_instancing: Option<bool>Is GPU draw call instancing supported?
supports_ray_tracing: Option<bool>Is ray tracing available on the device?
supports_compute_shaders: Option<bool>Are compute shaders available on the device?
supports_geometry_shaders: Option<bool>Are geometry shaders available on the device?
other: BTreeMap<String, Value>Additional arbitrary fields for forwards compatibility.