pub struct Span { /* private fields */ }Expand description
A running Performance Monitoring Span.
The span needs to be explicitly finished via Span::finish, otherwise it
will not be sent to Sentry.
Implementations
Sourceimpl Span
impl Span
Sourcepub fn set_data(&self, key: &str, value: Value)
pub fn set_data(&self, key: &str, value: Value)
Set some extra information to be sent with this Transaction.
Sourcepub fn data(&self) -> Data<'_>
pub fn data(&self) -> Data<'_>
Returns a smart pointer to the span’s data field.
Since Data implements Deref and DerefMut, this can be used to read and mutate
the span data.
Concurrency
In order to obtain any kind of reference to the data field,
a Mutex needs to be locked. The returned Data holds on to this lock
for as long as it lives. Therefore you must take care not to keep the returned
Data around too long or it will never relinquish the lock and you may run into
a deadlock.
Sourcepub fn get_trace_context(&self) -> TraceContext
pub fn get_trace_context(&self) -> TraceContext
Get the TransactionContext of the Span.
Note that this clones the underlying value.
Sourcepub fn get_span_id(&self) -> SpanId
pub fn get_span_id(&self) -> SpanId
Get the current span ID.
Sourcepub fn get_status(&self) -> Option<SpanStatus>
pub fn get_status(&self) -> Option<SpanStatus>
Get the status of the Span.
Sourcepub fn set_status(&self, status: SpanStatus)
pub fn set_status(&self, status: SpanStatus)
Set the status of the Span.
Sourcepub fn set_request(&self, request: Request)
pub fn set_request(&self, request: Request)
Set the HTTP request information for this Span.
Sourcepub fn iter_headers(&self) -> TraceHeadersIter ⓘ
pub fn iter_headers(&self) -> TraceHeadersIter ⓘ
Returns the headers needed for distributed tracing.
Use crate::Scope::iter_trace_propagation_headers to obtain the active
trace’s distributed tracing headers.
Sourcepub fn is_sampled(&self) -> bool
👎Deprecated: the returned value may not accurately represent the sampling decision
pub fn is_sampled(&self) -> bool
the returned value may not accurately represent the sampling decision
Get the sampling decision for this Span.
The returned bool does not fully represent the Span’s sampling state.
Although true reliably indicates that the Span is sampled, a value of
false can mean either that the Span is not sampled, or that tracing is
disabled and the sampling decision is deferred. This method therefore
should no longer be used, especially not for trace continuation purposes.
For trace propagation, use Self::iter_headers or
crate::Scope::iter_trace_propagation_headers instead, to ensure
correct results.
Sourcepub fn finish_with_timestamp(self, _timestamp: SystemTime)
pub fn finish_with_timestamp(self, _timestamp: SystemTime)
Finishes the Span with the provided end timestamp.
This will record the end timestamp and add the span to the transaction in which it was started.
Sourcepub fn finish(self)
pub fn finish(self)
Finishes the Span.
This will record the current timestamp as the end timestamp and add the span to the transaction in which it was started.
Sourcepub fn start_child(&self, op: &str, description: &str) -> Span
pub fn start_child(&self, op: &str, description: &str) -> Span
Starts a new child Span with the given op and description.
The span must be explicitly finished via Span::finish.