pub trait IntoDsn {
// Required method
fn into_dsn(self) -> Result<Option<Dsn>, ParseDsnError>;
}Expand description
Helper trait to convert a string into an Option<Dsn>.
This converts a value into a DSN by parsing. The empty string or null values result in no DSN being parsed.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".