CounterMetric

Struct CounterMetric 

pub struct CounterMetric { /* private fields */ }
A counter metric, created with counter.

Implementations

Source

impl CounterMetric

pub fn attribute<K, V>(self, key: K, value: V) -> Self
where K: Into<Cow<'static, str>>, V: Into<LogAttribute>,

Adds an attribute to the metric.

pub fn capture(self)

Captures the metric on the current Hub, sending it to Sentry.

If the current hub has no client, the metric is dropped. To capture on a different hub, use Hub::capture_metric.