DistributionMetric

Struct DistributionMetric 

pub struct DistributionMetric { /* private fields */ }
A distribution metric, created with distribution.

Implementations

Source

impl DistributionMetric

pub fn attribute<K, V>(self, key: K, value: V) -> Self
where K: Into<Cow<'static, str>>, V: Into<LogAttribute>,

Adds an attribute to the metric.

Attributes are keys that can be used to filter and group metrics in Sentry. Multiple attributes can be chained. We recommend using Sentry semantic conventions for key values, where applicable.

pub fn capture(self)

Captures the metric on the current Hub, sending it to Sentry.

If the current hub has no client bound, the metric is dropped. To capture on a different hub, use Hub::capture_metric.

Source

impl DistributionMetric

pub fn unit<U>(self, unit: U) -> Self
where U: Into<Unit>,

Sets the unit on the metric.