Unit

Enum Unit 

#[non_exhaustive]
pub enum Unit {
Show 25 variants Nanosecond, Microsecond, Millisecond, Second, Minute, Hour, Day, Week, Bit, Byte, Kilobyte, Kibibyte, Megabyte, Mebibyte, Gigabyte, Gibibyte, Terabyte, Tebibyte, Petabyte, Pebibyte, Exabyte, Exbibyte, Ratio, Percent, Other(Cow<'static, str>),
}
A unit for a metric.

Recognized units are explicitly enumerated, while other units can be set using the Unit::Other variant.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Nanosecond



Microsecond



Millisecond



Second



Minute



Hour



Day



Week



Bit



Byte



Kilobyte



Kibibyte



Megabyte



Mebibyte



Gigabyte



Gibibyte



Terabyte



Tebibyte



Petabyte



Pebibyte



Exabyte



Exbibyte



Ratio



Percent



Other(Cow<'static, str>)

Any other unit, which may not be recognized by the Sentry UI.

We advise against constructing this variant directly; instead, rely on the From implementations to convert from a String, Cow<'static, str>, or &'static str, as these implementations normalize to the known units, including to any units we may add in the future as we add them.