pub struct TracePropagationContext { /* private fields */ }Expand description
The trace propagation context.
Contains the information necessary for propagating Sentry traces and continuing traces from incoming requests.
The data stored in this struct can be parsed from and transmitted as sentry-trace and Sentry
baggage headers.
Note that the Rust SDK only partially supports trace propagation, certain features such as dynamic sampling may be missing or incomplete.
Implementations
Sourceimpl TracePropagationContext
impl TracePropagationContext
Sourcepub fn new(trace_id: TraceId, span_id: SpanId) -> Self
pub fn new(trace_id: TraceId, span_id: SpanId) -> Self
Creates a new TracePropagationContext from the provided parameters
Sourcepub fn with_sampled(self, sampled: bool) -> Self
pub fn with_sampled(self, sampled: bool) -> Self
Set the sampling decision on self.
Sourcepub fn sentry_trace_header(&self) -> String
pub fn sentry_trace_header(&self) -> String
Computes the sentry-trace header for this TracePropagationContext.
Sourcepub fn try_from_headers<'a, I>(headers: I) -> Result<Self, HeaderParseError>
pub fn try_from_headers<'a, I>(headers: I) -> Result<Self, HeaderParseError>
Attempt to parse a list of Sentry headers into TracePropagationContext.
The parsing will fail if there is no valid sentry-trace header.